% 
% program to generate displacement and strain for a screw
% dislocation. 
% 
clear i
clf
hold off i
% 
V=1; 
D=20000.; 
d=2000.;
dx=1000;
x0 = -512000:dx:512000; 
xp = x0/1000.; 
% 
% this first model has shallow creep between depths of d0 and d 
%
V1 = (V/pi)*(atan(x0/d)-atan(x0/D));
E1=diff(V1)/2.e6;
%
%  now read the strain from the grd file and compare
%
[x,y,vy]=grdread2('ym1.grd');
[x,y,exy]=grdread2('exy1.grd');
%
%  extract profiles
%
vyp=vy(64,513:1536);
exyp=exy(64,513:1536);
subplot(2,1,2);plot(xp/20,V1,(xp(1:length(vyp))+1)/20,vyp);
xlabel('distance (x/d)')
ylabel('displacement ')
xlim([-4 4])
subplot(2,1,1);plot((xp(1:length(E1))-.5)/20,E1,xp(1:length(exyp))/20,exyp);
xlabel('distance (x/d)')
ylabel('strain')
xlim([-4 4])
%
%  now plot the step results
%
mu1=1.;
mu2=.5;
N=length(x0);
V1=zeros(N,1);
V2=zeros(N,1);
for i=1:N
if x0(i) < 0
  V1(i)=2*V*(mu1/(mu1+mu2))*atan(D./x0(i))/pi;
  V2(i)=2*V*(mu1/(mu1+mu2))*atan(d/x0(i))/pi;
else
  V1(i)=2*V*(mu2/(mu1+mu2))*atan(D./x0(i))/pi;
  V2(i)=2*V*(mu2/(mu1+mu2))*atan(d/x0(i))/pi;
end
end
VT2=V1-V2;
E2=diff(VT2)/2.e6;
%
%  now read the strain from the grd file and compare
%
[x,y,vy]=grdread2('ym2.grd');
[x,y,exy]=grdread2('exy2.grd');
%
%  extract profiles
%
vyp=vy(64,513:1536);
exyp=exy(64,513:1536);
figure(2)
subplot(2,1,2);plot(xp/20,VT2,(xp(1:length(vyp))+1)/20,vyp-.044);
xlabel('distance (x/d)')
ylabel('displacement ')
xlim([-4 4])
ylim([-.5 .3])
subplot(2,1,1);plot((xp(1:length(E2))-.5)/20,E2,xp(1:length(exyp))/20,exyp);
xlabel('distance (x/d)')
ylabel('strain')
xlim([-4 4])
